@@ -1,4 +1,4 @@
-# $Id: muc.tcl 2014 2013-07-04 10:34:46Z sergei $
+# $Id$
 
 namespace eval muc {
     set winid 0
@@ -251,6 +251,14 @@ proc muc::add_muc_menu_items {m xlib group {state disabled}} {
 hook::add chat_create_conference_menu_hook \
 	  [namespace current]::muc::add_muc_menu_items 37
 
+proc muc::add_edit_info_menu_item {m xlib group} {
+    $m add command -label [::msgcat::mc "Edit room info..."] \
+       -command [list ::userinfo::open $xlib $group -editable 1]
+}
+
+hook::add chat_create_conference_menu_hook \
+	  [namespace current]::muc::add_edit_info_menu_item 37
+
 proc muc::disco_node_menu_setup {m bw tnode data parentdata} {
     lassign $data type xlib jid node
     switch -- $type {
