@@ -1,4 +1,4 @@
-# $Id: muc.tcl 2054 2014-01-07 17:19:42Z sergei $
+# $Id$
 
 # Multi-User Chat support (XEP-0045)
 
@@ -250,8 +250,10 @@ proc muc::receive_config {chatid res child} {
 
     ::xmpp::xml::split $child tag xmlns attrs cdata subels
 
-    data::draw_window $subels [list muc::send_config $chatid] \
-			      [list muc::cancel_config $chatid]
+    data::draw_window $subels \
+	[list muc::send_config $chatid] \
+	-cancelCommand [list muc::cancel_config $chatid] \
+	-title [::msgcat::mc "Configure room %s" $group]
     return
 }
 
